[gnome-packagekit] Consistently name gpk-prefs as Package Sources



commit a4082e9497c223a30a7ba9e33570a23de6aa03b4
Author: Michael Catanzaro <mcatanzaro gnome org>
Date:   Sat Dec 21 22:57:20 2013 -0600

    Consistently name gpk-prefs as Package Sources
    
    It was previously named Software Update Preferences, but the only
    remaining settings are for repository configuration.
    
    Additionally, be sure to consistently refer to these sources as "package
    sources."
    
    https://bugzilla.gnome.org/show_bug.cgi?id=720931

 data/gpk-application.ui               |    2 +-
 data/gpk-prefs.desktop.in             |    4 ++--
 data/gpk-prefs.ui                     |    6 +++---
 data/org.gnome.packagekit.gschema.xml |    4 ++--
 src/gpk-application.c                 |    2 +-
 src/gpk-dbus-task.c                   |   12 ++++++------
 src/gpk-enum.c                        |   26 +++++++++++++-------------
 src/gpk-prefs.c                       |   10 +++++-----
 src/org.freedesktop.PackageKit.xml    |   12 ++++++------
 9 files changed, 39 insertions(+), 39 deletions(-)
---
diff --git a/data/gpk-application.ui b/data/gpk-application.ui
index f7172c4..4611dc4 100644
--- a/data/gpk-application.ui
+++ b/data/gpk-application.ui
@@ -582,7 +582,7 @@
         <attribute name="action">app.updates</attribute>
       </item>
       <item>
-        <attribute name="label" translatable="yes">Software Sources</attribute>
+        <attribute name="label" translatable="yes">Package Sources</attribute>
         <attribute name="action">app.sources</attribute>
       </item>
       <item>
diff --git a/data/gpk-prefs.desktop.in b/data/gpk-prefs.desktop.in
index 80adc54..8573197 100644
--- a/data/gpk-prefs.desktop.in
+++ b/data/gpk-prefs.desktop.in
@@ -1,6 +1,6 @@
 [Desktop Entry]
-_Name=Software Settings
-_Comment=Change software update preferences and enable or disable software sources
+_Name=Package Sources
+_Comment=Enable or disable package repositories
 Icon=gpk-prefs
 Exec=gpk-prefs
 Terminal=false
diff --git a/data/gpk-prefs.ui b/data/gpk-prefs.ui
index f4f38a2..00e6176 100644
--- a/data/gpk-prefs.ui
+++ b/data/gpk-prefs.ui
@@ -5,7 +5,7 @@
   <object class="GtkDialog" id="dialog_prefs">
     <property name="can_focus">False</property>
     <property name="border_width">5</property>
-    <property name="title" translatable="yes">Software Update Preferences</property>
+    <property name="title" translatable="yes">Package Sources</property>
     <property name="default_height">450</property>
     <property name="type_hint">dialog</property>
     <child internal-child="vbox">
@@ -74,7 +74,7 @@
                 <property name="visible">True</property>
                 <property name="can_focus">False</property>
                 <property name="xalign">0</property>
-                <property name="label" translatable="yes">A software source contains packages that can be 
installed on this computer.</property>
+                <property name="label" translatable="yes">A package source contains packages that can be 
installed on this computer.</property>
                 <attributes>
                   <attribute name="style" value="normal"/>
                 </attributes>
@@ -109,7 +109,7 @@
             </child>
             <child>
               <object class="GtkCheckButton" id="checkbutton_detail">
-                <property name="label" translatable="yes" comments="shows extra -source, -debuginfo, and 
-devel software sources">_Show debug and development software sources</property>
+                <property name="label" translatable="yes" comments="shows extra -source, -debuginfo, and 
-devel sources">_Show debug and development package sources</property>
                 <property name="use_action_appearance">False</property>
                 <property name="visible">True</property>
                 <property name="can_focus">True</property>
diff --git a/data/org.gnome.packagekit.gschema.xml b/data/org.gnome.packagekit.gschema.xml
index 11d4698..35c50f3 100644
--- a/data/org.gnome.packagekit.gschema.xml
+++ b/data/org.gnome.packagekit.gschema.xml
@@ -57,8 +57,8 @@
     </key>
     <key name="repo-show-details" type="b">
       <default>false</default>
-      <summary>Show all repositories in the software source viewer</summary>
-      <description>Show all repositories in the software source viewer.</description>
+      <summary>Show all repositories in the package source viewer</summary>
+      <description>Show all repositories in the package source viewer.</description>
     </key>
     <key name="only-newest" type="b">
       <default>true</default>
diff --git a/src/gpk-application.c b/src/gpk-application.c
index 183919f..34ca06e 100644
--- a/src/gpk-application.c
+++ b/src/gpk-application.c
@@ -3417,7 +3417,7 @@ gpk_application_startup_cb (GtkApplication *application, GpkApplicationPrivate *
        g_signal_connect (selection, "changed",
                          G_CALLBACK (gpk_application_groups_treeview_changed_cb), priv);
 
-       /* get repos, so we can show the full name in the software source box */
+       /* get repos, so we can show the full name in the package source box */
        pk_client_get_repo_list_async (PK_CLIENT (priv->task),
                                       pk_bitfield_value (PK_FILTER_ENUM_NONE),
                                       priv->cancellable,
diff --git a/src/gpk-dbus-task.c b/src/gpk-dbus-task.c
index 677bdfa..18b597a 100644
--- a/src/gpk-dbus-task.c
+++ b/src/gpk-dbus-task.c
@@ -1086,7 +1086,7 @@ gpk_dbus_task_install_package_names_resolve_cb (PkTask *task, GAsyncResult *res,
                                gpk_modal_dialog_setup (dtask->priv->dialog, GPK_MODAL_DIALOG_PAGE_WARNING, 
0);
                        gpk_modal_dialog_set_title (dtask->priv->dialog, title);
                        /* TRANSLATORS: message: could not find */
-                       gpk_modal_dialog_set_message (dtask->priv->dialog, _("The packages could not be found 
in any software source"));
+                       gpk_modal_dialog_set_message (dtask->priv->dialog, _("The packages could not be found 
in any package source"));
                        gpk_modal_dialog_set_help_id (dtask->priv->dialog, "dialog-package-not-found");
                        /* TRANSLATORS: button: a link to the help file */
                        gpk_modal_dialog_set_action (dtask->priv->dialog, _("More information"));
@@ -1631,8 +1631,8 @@ gpk_dbus_task_codec_what_provides_cb (PkClient *client, GAsyncResult *res, GpkDb
                                gpk_modal_dialog_setup (dtask->priv->dialog, GPK_MODAL_DIALOG_PAGE_WARNING, 
0);
                        /* TRANSLATORS: failed to search for codec */
                        gpk_modal_dialog_set_title (dtask->priv->dialog, _("Failed to search for plugin"));
-                       /* TRANSLATORS: no software sources have the wanted codec */
-                       gpk_modal_dialog_set_message (dtask->priv->dialog, _("Could not find plugin in any 
configured software source"));
+                       /* TRANSLATORS: no package sources have the wanted codec */
+                       gpk_modal_dialog_set_message (dtask->priv->dialog, _("Could not find plugin in any 
configured package source"));
                        gpk_modal_dialog_set_help_id (dtask->priv->dialog, "dialog-package-not-found");
 
                        /* TRANSLATORS: button text */
@@ -1842,7 +1842,7 @@ gpk_dbus_task_mime_what_provides_cb (PkClient *client, GAsyncResult *res, GpkDbu
                                gpk_modal_dialog_setup (dtask->priv->dialog, GPK_MODAL_DIALOG_PAGE_WARNING, 
0);
                        /* TRANSLATORS: title */
                        gpk_modal_dialog_set_title (dtask->priv->dialog, _("Failed to find software"));
-                       /* TRANSLATORS: nothing found in the software sources that helps */
+                       /* TRANSLATORS: nothing found in the package sources that helps */
                        gpk_modal_dialog_set_message (dtask->priv->dialog, _("No new applications can be 
found to handle this type of file"));
                        gpk_modal_dialog_set_help_id (dtask->priv->dialog, "dialog-package-not-found");
                        /* TRANSLATORS: button: show the user a button to get more help finding stuff */
@@ -2441,8 +2441,8 @@ gpk_dbus_task_plasma_service_what_provides_cb (PkClient *client, GAsyncResult *r
                        else
                                gpk_modal_dialog_setup (dtask->priv->dialog, GPK_MODAL_DIALOG_PAGE_WARNING, 
0);
                        gpk_modal_dialog_set_title (dtask->priv->dialog, _("Failed to search for Plasma 
service"));
-                       /* TRANSLATORS: no software sources have the wanted Plasma service */
-                       gpk_modal_dialog_set_message (dtask->priv->dialog, _("Could not find service in any 
configured software source"));
+                       /* TRANSLATORS: no package sources have the wanted Plasma service */
+                       gpk_modal_dialog_set_message (dtask->priv->dialog, _("Could not find service in any 
configured package source"));
                        gpk_modal_dialog_set_help_id (dtask->priv->dialog, "dialog-package-not-found");
 
                        /* TRANSLATORS: button text */
diff --git a/src/gpk-enum.c b/src/gpk-enum.c
index 1609ec7..6d82245 100644
--- a/src/gpk-enum.c
+++ b/src/gpk-enum.c
@@ -358,7 +358,7 @@ gpk_error_enum_to_localised_text (PkErrorEnum code)
                text = _("Packages are not compatible");
                break;
        case PK_ERROR_ENUM_REPO_NOT_AVAILABLE:
-               text = _("Problem connecting to a software source");
+               text = _("Problem connecting to a package source");
                break;
        case PK_ERROR_ENUM_FAILED_INITIALIZATION:
                text = _("Failed to initialize");
@@ -518,14 +518,14 @@ gpk_error_enum_to_localised_message (PkErrorEnum code)
                         "Please report this bug in your distribution bug tracker with the error 
description.");
                break;
        case PK_ERROR_ENUM_GPG_FAILURE:
-               text = _("A security trust relationship could not be made with software source.\n"
+               text = _("A security trust relationship could not be made with package source.\n"
                         "Please check your security settings.");
                break;
        case PK_ERROR_ENUM_PACKAGE_NOT_INSTALLED:
                text = _("The package that is trying to be removed or updated is not already installed.");
                break;
        case PK_ERROR_ENUM_PACKAGE_NOT_FOUND:
-               text = _("The package that is being modified was not found on your system or in any software 
source.");
+               text = _("The package that is being modified was not found on your system or in any package 
source.");
                break;
        case PK_ERROR_ENUM_PACKAGE_ALREADY_INSTALLED:
                text = _("The package that is trying to be installed is already installed.");
@@ -559,8 +559,8 @@ gpk_error_enum_to_localised_message (PkErrorEnum code)
                         "More information is available in the detailed report.");
                break;
        case PK_ERROR_ENUM_REPO_NOT_FOUND:
-               text = _("The remote software source name was not found.\n"
-                        "You may need to enable an item in Software Sources.");
+               text = _("The remote package source name was not found.\n"
+                        "You may need to enable an item in Package Sources.");
                break;
        case PK_ERROR_ENUM_CANNOT_REMOVE_SYSTEM_PACKAGE:
                text = _("Removing a protected system package is not allowed.");
@@ -589,14 +589,14 @@ gpk_error_enum_to_localised_message (PkErrorEnum code)
                break;
        case PK_ERROR_ENUM_FILE_CONFLICTS:
                text = _("Two packages provide the same file.\n"
-                        "This is usually due to mixing packages from different software sources.");
+                        "This is usually due to mixing packages from different sources.");
                break;
        case PK_ERROR_ENUM_PACKAGE_CONFLICTS:
                text = _("Multiple packages exist that are not compatible with each other.\n"
-                        "This is usually due to mixing packages from different software sources.");
+                        "This is usually due to mixing packages from different sources.");
                break;
        case PK_ERROR_ENUM_REPO_NOT_AVAILABLE:
-               text = _("There was a (possibly temporary) problem connecting to a software source.\n"
+               text = _("There was a (possibly temporary) problem connecting to a package source.\n"
                         "Please check the detailed error for further details.");
                break;
        case PK_ERROR_ENUM_FAILED_INITIALIZATION:
@@ -649,11 +649,11 @@ gpk_error_enum_to_localised_message (PkErrorEnum code)
                         "Check the file still exists and has not been deleted.");
                break;
        case PK_ERROR_ENUM_NO_MORE_MIRRORS_TO_TRY:
-               text = _("Required data could not be found on any of the configured software sources.\n"
+               text = _("Required data could not be found on any of the configured package sources.\n"
                         "There were no more download mirrors that could be tried.");
                break;
        case PK_ERROR_ENUM_NO_DISTRO_UPGRADE_DATA:
-               text = _("Required upgrade data could not be found in any of the configured software 
sources.\n"
+               text = _("Required upgrade data could not be found in any of the configured package 
sources.\n"
                         "The list of distribution upgrades will be unavailable.");
                break;
        case PK_ERROR_ENUM_INCOMPATIBLE_ARCHITECTURE:
@@ -687,7 +687,7 @@ gpk_error_enum_to_localised_message (PkErrorEnum code)
                text = _("The information about what requires this package could not be obtained.");
                break;
        case PK_ERROR_ENUM_CANNOT_DISABLE_REPOSITORY:
-               text = _("The specified software source could not be disabled.");
+               text = _("The specified package source could not be disabled.");
                break;
        case PK_ERROR_ENUM_RESTRICTED_DOWNLOAD:
                text = _("The download could not be done automatically and should be done manually.\n"
@@ -723,7 +723,7 @@ gpk_error_enum_to_localised_message (PkErrorEnum code)
                text = _("The install root is invalid. Please contact your administrator.");
                break;
        case PK_ERROR_ENUM_CANNOT_FETCH_SOURCES:
-               text = _("The list of software sources could not be downloaded.");
+               text = _("The list of package sources could not be downloaded.");
                break;
        case PK_ERROR_ENUM_UNFINISHED_TRANSACTION:
                text = _("A previous package management transaction was interrupted.");
@@ -1578,7 +1578,7 @@ gpk_group_enum_to_localised_text (PkGroupEnum group)
                break;
        case PK_GROUP_ENUM_REPOS:
                /* TRANSLATORS: The group type */
-               text = _("Software sources");
+               text = _("Package sources");
                break;
        case PK_GROUP_ENUM_SCIENCE:
                /* TRANSLATORS: The group type */
diff --git a/src/org.freedesktop.PackageKit.xml b/src/org.freedesktop.PackageKit.xml
index 38be726..64a6c45 100644
--- a/src/org.freedesktop.PackageKit.xml
+++ b/src/org.freedesktop.PackageKit.xml
@@ -208,7 +208,7 @@
       <doc:doc>
         <doc:description>
           <doc:para>
-            Installs packages from a configured software source.
+            Installs packages from a configured package source.
           </doc:para>
         </doc:description>
       </doc:doc>
@@ -248,7 +248,7 @@
       <doc:doc>
         <doc:description>
           <doc:para>
-            Installs mimetype handlers from a configured software source.
+            Installs mimetype handlers from a configured package source.
           </doc:para>
         </doc:description>
       </doc:doc>
@@ -288,7 +288,7 @@
       <doc:doc>
         <doc:description>
           <doc:para>
-            Installs fontconfig resources (usually fonts) from a configured software source.
+            Installs fontconfig resources (usually fonts) from a configured package source.
           </doc:para>
         </doc:description>
       </doc:doc>
@@ -328,7 +328,7 @@
       <doc:doc>
         <doc:description>
           <doc:para>
-            Installs GStreamer fontconfig resources (usually codecs) from a configured software source.
+            Installs GStreamer fontconfig resources (usually codecs) from a configured package source.
           </doc:para>
         </doc:description>
       </doc:doc>
@@ -369,7 +369,7 @@
       <doc:doc>
         <doc:description>
           <doc:para>
-            Installs resources of a given type from a configured software source.
+            Installs resources of a given type from a configured package source.
           </doc:para>
         </doc:description>
       </doc:doc>
@@ -465,7 +465,7 @@
       <doc:doc>
         <doc:description>
           <doc:para>
-            Installs printer drivers from a configured software source.
+            Installs printer drivers from a configured package source.
           </doc:para>
         </doc:description>
       </doc:doc>


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/src/gpk-prefs.c b/src/gpk-prefs.c
index 82a1627..1189967 100644
--- a/src/gpk-prefs.c
+++ b/src/gpk-prefs.c
@@ -240,7 +240,7 @@ gpk_prefs_repo_enable_cb (GObject *object, GAsyncResult *res, GpkPrefsPrivate *p
        if (error_code != NULL) {
                g_warning ("failed to set repo: %s, %s", pk_error_enum_to_string (pk_error_get_code 
(error_code)), pk_error_get_details (error_code));
                window = GTK_WINDOW (gtk_builder_get_object (priv->builder, "dialog_prefs"));
                /* TRANSLATORS: for one reason or another, we could not enable or disable a software source */
                gpk_error_dialog_modal (window, _("Failed to change status"),
                                        gpk_error_enum_to_localised_text (pk_error_get_code (error_code)), 
pk_error_get_details (error_code));
                goto out;
@@ -320,7 +320,7 @@ gpk_treeview_add_columns (GpkPrefsPrivate *priv, GtkTreeView *treeview)
        /* column for text */
        renderer = gtk_cell_renderer_text_new ();
        /* TRANSLATORS: column for the source description */
-       column = gtk_tree_view_column_new_with_attributes (_("Software Source"), renderer,
+       column = gtk_tree_view_column_new_with_attributes (_("Package Source"), renderer,
                                                           "markup", GPK_COLUMN_TEXT,
                                                           NULL);
        gtk_tree_view_column_set_sort_column_id (column, GPK_COLUMN_TEXT);
@@ -510,7 +510,7 @@ gpk_prefs_get_properties_cb (GObject *object, GAsyncResult *res, GpkPrefsPrivate
                gtk_list_store_append (GTK_LIST_STORE(model), &iter);
                gtk_list_store_set (priv->list_store, &iter,
                                    GPK_COLUMN_ENABLED, FALSE,
-                                   GPK_COLUMN_TEXT, _("Getting software source list not supported by 
backend"),
+                                   GPK_COLUMN_TEXT, _("Getting package source list not supported by 
backend"),
                                    GPK_COLUMN_ACTIVE, FALSE,
                                    GPK_COLUMN_SENSITIVE, FALSE,
                                    -1);
@@ -630,8 +630,8 @@ gpm_prefs_commandline_cb (GApplication *application,
        argv = g_application_command_line_get_arguments (cmdline, &argc);
 
        context = g_option_context_new (NULL);
-       /* TRANSLATORS: program name, an application to set per-user policy for updates */
-       g_option_context_set_summary(context, _("Software Update Preferences"));
+       /* TRANSLATORS: program name, an application to add and remove software repositories */
+       g_option_context_set_summary(context, _("Package Sources"));
        g_option_context_add_main_entries (context, options, NULL);
        g_option_context_add_group (context, gpk_debug_get_option_group ());
        ret = g_option_context_parse (context, &argc, &argv, NULL);
@@ -240,7 +240,7 @@ gpk_prefs_repo_enable_cb (GObject *object, GAsyncResult *res, GpkPrefsPrivate *p
(error_code)), pk_error_get_details (error_code));
                window = GTK_WINDOW (gtk_builder_get_object (priv->builder, "dialog_prefs"));
-               /* TRANSLATORS: for one reason or another, we could not enable or disable a software source */
+               /* TRANSLATORS: for one reason or another, we could not enable or disable a package source */
                gpk_error_dialog_modal (window, _("Failed to change status"),
                                        gpk_error_enum_to_localised_text (pk_error_get_code (error_code)), 